@@ -13,18 +13,16 @@ __all__ = ['Dataset', 'shuffle_dataset']
 
 
 class Dataset(RandomDataPipe, RawDataset):
-    def __init__(self, data, kind=DataKind.MEM_SEQ, filename=''):
+    def __init__(self, data, kind=DataKind.MEM_SEQ):
         """
 
         Args:
             data:
               - list of things: if kind=DataKind.MEM_SEQ
-              - filename: if kind=DataKind.FILE
-              - mmap: if kind=DataKind.MMAP_FILE
+              - filename: if kind=DataKind.FILE or kind=DataKind.MMAP_FILE
             kind: @see DataKind
-            filename: only valid if kind=DataKind.MMAP_FILE
         """
-        super().__init__(data, kind, filename=filename)
+        super().__init__(data, kind)
 
         self._local_rng = get_rng(self)
 
